# Main loop to generate LC50 values (w/ uncertainty) from models
#
# Expects a list of list of glm named model_grid, with 
#   the outer index being age and the inner index being treatment
# Expects a numeric scalar named p (p = 0.50 for LD50)
# Expects a numeric scalar named alpha
#
# Requires library MASS
#
# Generate a data.frame named dosage, as well as
# auxillary vectors named ages and treatments

dosage <- data.frame();
ages <- names(model_grid);
for (i in ages){
    tmp <- model_grid[[i]];
    treatments <- names(tmp);
    for (val in treatments){
        model <- tmp[[val]];
        log10Temp <- dose.p(model, p=p);
        dose_p <- attr(log10Temp, "p");
        log10SE <- attr(log10Temp, "SE");
        attributes(log10Temp) <- NULL;
        qtl <- qnorm(1 - alpha/2);
        Temp <- 10 ^ (log10Temp);
        lower <- 10 ^ (log10Temp - qtl * log10SE);
        upper <- 10 ^ (log10Temp + qtl * log10SE);
        ddosage <- list(
            age=i, treatment=val, 
            p=dose_p, losg10.Temp=log10Temp, log10.SE=log10SE, 
            Temp=Temp, lower=lower, upper=upper
        )
        dosage <- rbind(dosage, ddosage);
    }
}
colnames(dosage) <- c(
    "Age", "Treatment", "p", "log10.Temp", "log10.SE", 
    "Temp", "lower", "upper"
)

# clean-up
rm(i, val, tmp, model, log10Temp, dose_p, log10SE, qtl, Temp, lower, upper, ddosage)